import { DefaultIdentifyService } from './identify.js';
import { Identify } from './pb/message.js';
import type { Libp2pEvents } from '@libp2p/interface';
import type { EventEmitter } from '@libp2p/interface/events';
import type { PeerId } from '@libp2p/interface/peer-id';
import type { PeerStore } from '@libp2p/interface/peer-store';
import type { AddressManager } from '@libp2p/interface-internal/address-manager';
import type { ConnectionManager } from '@libp2p/interface-internal/connection-manager';
import type { Registrar } from '@libp2p/interface-internal/registrar';
export interface IdentifyServiceInit {
    /**
     * The prefix to use for the protocol (default: 'ipfs')
     */
    protocolPrefix?: string;
    /**
     * What details we should send as part of an identify message
     */
    agentVersion?: string;
    /**
     * How long we should wait for a remote peer to send their identify response
     */
    timeout?: number;
    /**
     * Identify responses larger than this in bytes will be rejected (default: 8192)
     */
    maxIdentifyMessageSize?: number;
    maxInboundStreams?: number;
    maxOutboundStreams?: number;
    maxPushIncomingStreams?: number;
    maxPushOutgoingStreams?: number;
    maxObservedAddresses?: number;
}
export interface IdentifyServiceComponents {
    peerId: PeerId;
    peerStore: PeerStore;
    connectionManager: ConnectionManager;
    registrar: Registrar;
    addressManager: AddressManager;
    events: EventEmitter<Libp2pEvents>;
}
/**
 * The protocols the IdentifyService supports
 */
export declare const multicodecs: {
    IDENTIFY: string;
    IDENTIFY_PUSH: string;
};
export declare const Message: {
    Identify: typeof Identify;
};
export declare function identifyService(init?: IdentifyServiceInit): (components: IdentifyServiceComponents) => DefaultIdentifyService;
//# sourceMappingURL=index.d.ts.map